## 3.2.4 (2024-01-03)

### Improvements

- Bump docker github action ([4474f52](https://github.com/kpn/cz-kpn/commit/4474f52cf3334aaa5713651b3642d5ff1cf75256))

## 3.2.3 (2023-09-08)

### Improvements

- **ci**: Add sleep to let pypi publish py package ([625c993](https://github.com/kpn/cz-kpn/commit/625c9931d81325475ce227695bc854024da5471e))

## 3.2.2 (2023-09-08)

### Fixes

- Get current version in action ([233eaef](https://github.com/kpn/cz-kpn/commit/233eaef820a0ab941c73f6d2ce7385f0353c22ed))

## 3.2.1 (2023-09-08)

### Fixes

- Update dependencies ([d29c7d0](https://github.com/kpn/cz-kpn/commit/d29c7d0482e5c80ef0defcbfc4cc51f5ff18ca74))
- Add cz-kpn to github action ([54b9239](https://github.com/kpn/cz-kpn/commit/54b9239cd62538462adb9ce39b565bf7bab7fd36))

### Improvements

- Add repo badges ([568ad62](https://github.com/kpn/cz-kpn/commit/568ad62dc6fbe03ca415dcecb6c7d50458eab67d))
- Update pyproject.toml ([8ff761d](https://github.com/kpn/cz-kpn/commit/8ff761d9530654fbeb3112120ed09aed3a196a1b))
- Docker release ([4d8323c](https://github.com/kpn/cz-kpn/commit/4d8323c0d7ed922eb4b71dbf80065b361c7d2811))

## 3.2.0 (2023-09-08)

### Features

- Open source cz-kpn ([003ab88](https://github.com/kpn/cz-kpn/commit/003ab88d93f09a7b90b2bb144b8cd9d62419375f))
